@@ -80,100 +80,6 @@ C
 C Set arrays in module cglow (formerly COMMON/CXSECT/)
 C (all are dimensioned (nei,nmaj) (10,3))
 C
-      WW(1:nei,1)=
-     |  (/1.96, 4.17, 9.29, 9.53,10.76,10.97,12.07,12.54, 0., 0./)
-      WW(1:nei,2)=
-     |  (/0.98, 1.64, 4.50, 8.44, 9.90,13.50, 0.25, 0.00, 0., 0./)
-      WW(1:nei,3)=
-     |  (/6.17, 8.16,11.03, 8.40,12.85,14.00,13.75, 1.85, 0., 0./)
-
-      AO(1:nei,1)=
-     |  (/.0100,.0042,.1793,.3565,.0327,.0245,.0293,.1221, 0.,0./)
-      AO(1:nei,2)=
-     |  (/.0797,.0211,.0215,.3400,.0657,1.110,3.480, 0.00, 0.,0./)
-      AO(1:nei,3)=
-     |  (/2.770,.1140,.1790,.0999,.8760,.6010,1.890,1.350, 0.,0./)
-
-      OMEG(1:nei,1)=
-     |  (/1.00, 1.00, 3.00, 0.75, 3.00, 0.85, 0.75, 0.75, 0.,0./)
-      OMEG(1:nei,2)=
-     |  (/2.00, 2.00, 1.15, 0.75, 0.75, 0.75, 7.00, 0.00, 0.,0./)
-      OMEG(1:nei,3)=
-     |  (/3.00, 3.00, 3.00, 1.00, 0.75, 0.75, 0.75, 8.00, 0.,0./)
-
-      ANU(1:nei,1)=
-     |  (/2.00, 1.04, 2.53, 0.54, 2.43, 2.87, 0.93, 0.72, 0.,0./)
-      ANU(1:nei,2)=
-     |  (/6.18, 4.14, 1.00, 1.05, 1.60, 3.00,10.87, 0.00, 0.,0./)
-      ANU(1:nei,3)=
-     |  (/4.53, 4.78, 4.32, 4.05, 1.47, 1.27, 3.00, 1.58, 0.,0./)
-
-      BB(1:nei,1)=
-     |  (/1.00, 0.50, 1.02, 0.01, 4.19, 4.88, 0.66, 0.17, 0.,0./)
-      BB(1:nei,2)=
-     |  (/0.53, 0.51, 0.98, 0.99, 1.86, 1.00, 1.00, 0.00, 0.,0./)
-      BB(1:nei,3)=
-     |  (/1.42, 3.54,12.70, 5.20, 0.86, 0.45, 1.00, 1.00, 0.,0./)
-
-      AUTO(1:nei,1) = (/0.,0.,0.,0.,0.,0.,0.,0.,0.,0./)
-      AUTO(1:nei,2) = (/0.,0.,0.,0.,0.,0.,0.,0.,0.,0./)
-      AUTO(1:nei,3) = (/0.,0.,0.,0.,0.,0.,0.,0.,0.,0./)
-
-      THI(1:nei,1)=
-     |  (/13.60,16.90,18.50, 0.00, 0.00, 0.00, 0.00, 0.,0.,0./)
-      THI(1:nei,2)=
-     |  (/12.10,16.10,16.90,18.20,20.00,23.00,37.00, 0.,0.,0./)
-      THI(1:nei,3)=
-     |  (/15.58,16.73,18.75,22.00,23.60,40.00, 0.00, 0.,0.,0./)
-
-      AK(1:nei,1)=
-     |  (/ 1.13, 1.25, 0.67, 0.00, 0.00, 0.00, 0.00, 0.,0.,0./)
-      AK(1:nei,2)=
-     |  (/0.47, 1.13, 1.13, 1.01, 0.65, 0.95, 0.59, 0.,0.,0./)
-      AK(1:nei,3)=
-     |  (/2.42, 1.06, 0.55, 0.37, 0.37, 0.53, 0.00, 0.,0.,0./)
-
-      AJ(1:nei,1)=
-     |  (/1.81, 1.79, 1.78, 0.00, 0.00, 0.00, 0.00, 0.,0.,0./)
-      AJ(1:nei,2)=
-     |  (/3.76, 3.76, 3.76, 3.76, 3.76, 3.76, 3.76, 0.,0.,0./)
-      AJ(1:nei,3)=
-     |  (/1.74, 1.74, 1.74, 1.74, 1.74, 1.74, 0.00, 0.,0.,0./)
-
-      TS(1:nei,1)=
-     |  (/6.41, 6.41, 6.41, 0.00, 0.00, 0.00, 0.00, 0.,0.,0./)
-      TS(1:nei,2)=
-     |  (/1.86, 1.86, 1.86, 1.86, 1.86, 1.86, 1.86, 0.,0.,0./)
-      TS(1:nei,3)=
-     |  (/4.71, 4.71, 4.71, 4.71, 4.71, 4.71, 0.00, 0.,0.,0./)
-
-      TA(1:nei,1)=
-     |  (/3450.,3450.,3450.,   0.,   0.,   0.,   0., 0.,0.,0./)
-      TA(1:nei,2)=
-     |  (/1000.,1000.,1000.,1000.,1000.,1000.,1000., 0.,0.,0./)
-      TA(1:nei,3)=
-     |  (/1000.,1000.,1000.,1000.,1000.,1000.,   0., 0.,0.,0./)
-
-      TB(1:nei,1)=
-     |  (/162.00,162.0,162.0, 0.00, 0.00, 0.00, 0.00, 0.,0.,0./)
-      TB(1:nei,2)=
-     |  (/24.20,32.20,33.80,36.40,40.60,46.00,74.00, 0.,0.,0./)
-      TB(1:nei,3)=
-     |  (/31.16,33.46,37.50,44.00,47.20,80.00, 0.00, 0.,0.,0./)
-
-      GAMS(1:nei,1)=
-     |  (/13.00,13.0,13.00, 0.00, 0.00, 0.00, 0.00, 0.,0.,0./)
-      GAMS(1:nei,2)=
-     |  (/18.50,18.5,18.50,18.50,18.50,18.50,18.50, 0.,0.,0./)
-      GAMS(1:nei,3)=
-     |  (/13.80,13.8,13.80,13.80,13.80,13.80, 0.00, 0.,0.,0./)
-
-      GAMB(1:nei,1)=
-     |  (/-.815,-.815,-.815,0.00, 0.00, 0.00, 0.00, 0.,0.,0./)
-      GAMB(1:nei,2)=
-     |  (/12.10,16.10,16.90,18.2,20.30,23.00,37.00, 0.,0.,0./)
-      GAMB(1:nei,3)=
-     |  (/15.58,16.73,18.75,22.0,23.60,40.00, 0.00, 0.,0.,0./)
 
       EC(1:31,1) = (/
      |               1.00,     2.00,     4.00,     6.00,     8.00,
