@@ -22,14 +22,6 @@
 ! grazing height is lower than the bottom of the atmosphere supplied, 
 ! column densities are set to 'infinity', i.e., 1.0e30.
 
-! Input:
-!   CHI    Zenith angle (radians)
-!   ZZ     Altitude array; cm [jmax]
-!   ZMAJ   Major species number densities (O, O2, N2); cm-3 [nmaj,jmax]
-!   TN     Neutral temperature at each altitude; K [jmax]
-! Output:
-!   ZCOL   Slant column density (O, O2, N2); cm-2 [nmaj,jmax]
-!   ZVCD   Vertical column density (O, O2, N2) above each altitude (cumsum); cm-2 [nmaj,jmax]
 
     subroutine rcolum (chi, zz, zmaj, tn, zcol, zvcd, jmax, nmaj)
 
@@ -49,7 +41,6 @@
 
       call vcd (zz, zmaj, zvcd, jmax, nmaj)
 
-      ! Infinity case
       if (chi >= 2.) then 
         do i=1,nmaj
           do j=1,jmax
@@ -59,27 +50,26 @@
         return
       endif
 
-      ! Valid case
       if (chi <= pi/2.) then
         do i=1,nmaj
           do j=1,jmax
             zcol(i,j) = zvcd(i,j) * chap(chi,zz(j),tn(j),i)
           enddo
         enddo
-      else ! pi/2 < chi < 2
+      else
         do j=1,jmax
           ghrg=(re+zz(j))*sin(chi) 
           ghz=ghrg-re 
-          if (ghz <= zz(1)) then ! grazing height below lower boundary
+          if (ghz <= zz(1)) then
             do i=1,nmaj
-              zcol(i,j) = 1.0e30 ! set to 'infinity'
+              zcol(i,j) = 1.0e30
             enddo
           else
             do k=1,j-1
-              if (zz(k) <= ghz .and. zz(k+1) > ghz) then ! find correct height index
-                tng = tn(k)+(tn(k+1)-tn(k))*(ghz-zz(k))/(zz(k+1)-zz(k)) ! interpolate temperature
+              if (zz(k) <= ghz .and. zz(k+1) > ghz) then
+                tng = tn(k)+(tn(k+1)-tn(k))*(ghz-zz(k))/(zz(k+1)-zz(k))
                 do i=1,nmaj
-                  zcg(i) = zvcd(i,k) * (zvcd(i,k+1) / zvcd(i,k)) ** & ! interpolate vertical column
+                  zcg(i) = zvcd(i,k) * (zvcd(i,k+1) / zvcd(i,k)) ** &
                            ((ghz-zz(k)) / (zz(k+1)-zz(k)))
                 enddo
               endif
@@ -98,7 +88,6 @@
 
 !----------------------------------------------------------------------
 
-    ! Calculate Chapman Grazing Incidence Integral
     real function chap (chi, z, t, i)
 
       implicit none
@@ -108,18 +97,18 @@
 
       integer,parameter ::  nmaj=3
       real,parameter :: pi=3.1415926536
-      real,parameter :: re=6.37e8 ! cm
-      real,parameter :: g=978.1 ! cm/s^2
+      real,parameter :: re=6.37e8
+      real,parameter :: g=978.1
 
       real :: am(nmaj), gr, hn, hg, hf, sqhf
       real,external :: sperfc
 
       data am/16., 32., 28./
 
-      gr=g*(re/(re+z))**2 ! effective g
-      hn=1.38e-16*t/(am(i)*1.662e-24*gr) ! k_B * T / mass (amu * grams/amu or Dalton) * g
-      hg=(re+z)/hn ! gravitational scale height
-      hf=0.5*hg*(cos(chi)**2)
+      gr=g*(re/(re+z))**2 
+      hn=1.38e-16*t/(am(i)*1.662e-24*gr)
+      hg=(re+z)/hn 
+      hf=0.5*hg*(cos(chi)**2) 
       sqhf=sqrt(hf) 
       chap=sqrt(0.5*pi*hg)*sperfc(sqhf) 
 
@@ -148,9 +137,6 @@
 
 !----------------------------------------------------------------------
 
-    !Subroutine VCD
-    ! Calculates the cumulative vertical column density
-    ! for each species ZMAJ above each altitude ZZ.
     subroutine vcd(zz,zmaj,zvcd,jmax,nmaj)
 
       implicit none
@@ -169,7 +155,7 @@
                        / alog(zmaj(i,jmax-1)/zmaj(i,jmax))
         do j=jmax-1,1,-1
           rat = zmaj(i,j+1) / zmaj(i,j)
-          zvcd(i,j) = zvcd(i,j+1)+zmaj(i,j)*(zz(j)-zz(j+1))/alog(rat)*(1.0-rat)
+          zvcd(i,j) = zvcd(i,j+1)+zmaj(i,j)*(zz(j)-zz(j+1))/alog(rat)*(1.-rat)
         enddo
       enddo
 
